﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

# Note that many of these screens may be given additional arguments in the
# future. The use of **kwargs in the parameter list ensures your code will
# work in the future.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say(who, what, side_image=None, two_window=False):

    # Decide if we want to use the one-window or two-window variant.
    if not two_window:

        # The one window variant.
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:
                window:
                    style "say_who_window"

                    text who:
                        id "who"

            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"

    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0



##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):

    window:
        style "menu_window"
        xalign 0.5
        yalign 0.5

        vbox:
            style "menu"
            spacing 2

            for caption, action, chosen in items:

                if action:

                    button:
                        action action
                        style "menu_choice_button"

                        text caption style "menu_choice"

                else:
                    text caption style "menu_caption"

init -2:
    $ config.narrator_menu = True

    style menu_window is default

    style menu_choice is button_text:
        clear

    style menu_choice_button is button:
        xminimum int(config.screen_width * 0.75)
        xmaximum int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu

##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0

    use quick_menu

##############################################################################
# Main Menu
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    # This ensures that any other menu screen is replaced.
    tag menu

    imagemap:
        ground "images/gui/mainmenuidle.png"
        idle "images/gui/mainmenuidle.png"
        hover "images/gui/mainmenuhover.png"

        hotspot (80, 323, 116, 206) action Start() 
        hotspot (259, 323, 116, 206) action ShowMenu("load") 
        hotspot (438, 323, 116, 206) action ShowMenu("credits") 
        hotspot (617, 323, 116, 206) action ShowMenu("preferences") 
        hotspot (796, 315, 116, 206) action Quit() 

init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"



##############################################################################

# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation():

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Return") action Return()
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Save Game") action ShowMenu("save")
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Main Menu") action MainMenu()
        textbutton _("Help") action Help()
        textbutton _("Quit") action Quit()

init -2:

    # Make all game menu navigation buttons the same size.
    style gm_nav_button:
        size_group "gm_nav"


##############################################################################

#Pause Menu/Game Menu

screen pause_menu():

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    imagemap:
        ground "images/gui/navigation_ground.png"
        idle "images/gui/navigation_idle.png"
        hover "images/gui/navigation_selected.png"
        selected_idle "images/gui/navigation_selected.png"
        selected_hover "images/gui/navigation_selected_hover.png"        
        alpha False
        # This is so that everything transparent is invisible to the cursor.
        
        hotspot (644,96,39,39) action Return()
        hotspot (448,293,152,33) action Return()
        hotspot (448,341,152,33) action ShowMenu("preferences")
        hotspot (448,389,152,33) action ShowMenu("save")
        hotspot (448,439,152,33) action ShowMenu("load")
        hotspot (448,490,152,33) action MainMenu("preferences")
        hotspot (448,539,152,33) action ShowMenu("credits")
        hotspot (448,590,152,33) action Quit()



##############################################################################

# Credits
#
# Screen that gives credit to all the awesome people who helped make this game

screen credits():

    tag menu
    
    imagemap:
        ground 'images/gui/creditsidle.png'
        idle 'images/gui/creditsidle.png' 
        hover 'images/gui/creditshover.png'
        
        hotspot (955, 20, 45, 45) action Return()
        
init -2 python:
    
    style.imagemap_button.hover_sound = "sound/196979__peepholecircus__sci-fi-button-beep.wav"


##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.

screen save:
    
    tag menu

    imagemap:
        
        ground "images/gui/saveground.png"
        idle "images/gui/saveidle.png"
        hover "images/gui/savehover.png"
        selected_idle "images/gui/saveselectedidle.png"
          
        hotspot (107, 346, 230, 176) clicked FileSave(1):
            use load_save_slot(number=1)

        hotspot (389, 346, 230, 176) clicked FileSave(2):
            use load_save_slot(number=2)

        hotspot (672, 346, 230, 176) clicked FileSave(3):
            use load_save_slot(number=3)

            
        hotspot (312, 340, 39, 38) action FileDelete(1) 
        hotspot (594, 340, 39, 38) action FileDelete(2) 
        hotspot (877, 340, 39, 38) action FileDelete(3) 
            
        hotspot (416, 604, 36, 41) clicked FilePage(1)
        hotspot (491, 604, 36, 41) clicked FilePage(2) 
        hotspot (570, 604, 36, 41) clicked FilePage(3) 
            
        hotspot (297, 603, 40, 40) clicked FilePagePrevious() 
        hotspot (683, 603, 40, 40) clicked FilePageNext(max=3)
        
        hotspot (961, 19, 39, 39) action Return() 

screen load:
   
   tag menu

   imagemap:
        ground "images/gui/loadground.png"
        idle "images/gui/loadidle.png"
        hover "images/gui/loadhover.png"
        selected_idle "images/gui/loadselectedidle.png"
          
        hotspot (107, 346, 230, 176) clicked FileLoad(1):
            use load_save_slot(number=1)

        hotspot (389, 346, 230, 176) clicked FileLoad(2):
            use load_save_slot(number=2)

        hotspot (672, 346, 230, 176) clicked FileLoad(3):
            use load_save_slot(number=3)

            
            
        hotspot (312, 340, 39, 38) action FileDelete(1)
        hotspot (594, 340, 39, 38) action FileDelete(2)
        hotspot (877, 340, 39, 38) action FileDelete(3)
            
        hotspot (416, 604, 36, 41) clicked FilePage(1)
        hotspot (491, 604, 36, 41) clicked FilePage(2)
        hotspot (570, 604, 36, 41) clicked FilePage(3)
            
        hotspot (297, 603, 40, 40) clicked FilePagePrevious()
        hotspot (683, 603, 40, 40) clicked FilePageNext(max=3)
        
        hotspot (961, 19, 39, 39) action Return()
        
screen load_save_slot:
    $ file_text = "% 2s. %s\n%s" % (
                        FileSlotName(number, 3),
                        FileTime(number, empty=_("Empty Slot")),
                        FileSaveName(number))


    add FileScreenshot(number) xpos 10 ypos 10
  
init -2 python:
    config.thumbnail_width = 215
    config.thumbnail_height = 160



##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences:


    tag menu
    
    add "images/gui/optionsbg.png"
    
    imagemap:
            
            ground "images/gui/pm_idle.png"
            hover "images/gui/pm_hover.png"
            selected_idle "images/gui/pm_hover.png"
            alpha False
            cache False
            
            hotspot (276,362,95,22) action Preference("display", "window") 
            hotspot (388,362,90,22) action Preference("display", "fullscreen") 
            hotspot (304,578,28,22) action Preference("transitions", "all") 
            hotspot (345,578,47,22) action Preference("transitions", "none") 
            
            bar pos (302,471) value Preference("text speed") style "pref_slider"
            
            hotspot (647,578,44,22) action Preference("skip", "seen")
            hotspot (707,578,29,22) action Preference("skip", "all")
            
            bar pos (705,416) value Preference("music volume") style "pref_slider"
            
            bar pos (705,449) value Preference("sound volume") style "pref_slider"
            
            bar pos (705,481) value Preference("voice volume") style "pref_slider"
            
            hotspot (959, 21, 39, 39) action Return()
            


init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 8
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.left_bar = "images/gui/bar_full.png"
    style.pref_slider.right_bar = "images/gui/bar_empty.png"
    style.pref_slider.hover_left_bar = "images/gui/bar_full.png"
    style.pref_slider.ymaximum = 20
    style.pref_slider.xmaximum = 180
    style.pref_slider.thumb = None


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt

screen yesno_prompt:
    on "show" action With(dissolve)
    
    #modal True
    
    add "images/gui/yesno_background.png"
    
    imagemap:
        ground 'images/gui/yesno_ground.png'
        idle 'images/gui/yesno_idle.png' 
        hover 'images/gui/yesno_hover.png'
        alpha True
        # This is so that everything transparent is invisible to the cursor.
        
        
        hotspot (391, 406, 119, 50) action yes_action 
        hotspot (530, 406, 119, 50) action no_action 
        hotspot (768, 216, 38, 38) action Return()
  

    if message == layout.ARE_YOU_SURE:
        add "images/gui/yesno_are_you_sure.png"
        
    elif message == layout.DELETE_SAVE:
        add "images/gui/yesno_delete_save.png"
        
    elif message == layout.OVERWRITE_SAVE:
        add "images/gui/yesno_overwrite_save.png"
        
    elif message == layout.LOADING:
        add "images/gui/yesno_load_save.png"
        
    elif message == layout.QUIT:
        add "images/gui/yesno_quit.png"
        
    elif message == layout.MAIN_MENU:
        add "images/gui/yesno_main_menu.png"
        

init python:
    config.quit_action = Quit()



##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu():

    # Add an in-game quick menu.
    hbox:
        style_group "quick"

        xalign 1.0
        yalign 1.0

        textbutton _("Back") action Rollback()
        textbutton _("Save") action ShowMenu('save')
        textbutton _("Q.Save") action QuickSave()
        textbutton _("Q.Load") action QuickLoad()
        textbutton _("Skip") action Skip()
        textbutton _("F.Skip") action Skip(fast=True, confirm=True)
        textbutton _("Auto") action Preference("auto-forward", "toggle")
        textbutton _("Prefs") action ShowMenu('preferences')

init -2:
    style quick_button:
        is default
        background None
        xpadding 5

    style quick_button_text:
        is default
        size 12
        idle_color "#8888"
        hover_color "#ccc"
        selected_idle_color "#cc08"
        selected_hover_color "#cc0"
        insensitive_color "#4448"

